# enough_cards

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

```sh
pip install enough_cards
```

## How to use

The lib
[`Card`](https://genughaben.github.io/enough_cards/card.html#card) helps
to create and compare playing cards

```python
Card(1,2)
```

    ♠️2

```python
Card(1,2) < Card(1,1)
```

    False
